package Qt::Gui::QLinearGradient;
# THE FOLLOWING CODE IS AUTOMATED, ANY MODIFICATION WILL BE LOST!
# classname: QLinearGradient
# file     : QtGui/qbrush.h

use strict;
use warnings;
#use Carp;

our $VERSION = '0.01_03';
use base qw/Qt::Gui::QGradient/;
#our @ISA = qw/Qt::Gui::QGradient/;


# FIXME: operator overload


1;

=head1 NAME

Qt::Gui::QLinearGradient

=head1 PUBLIC METHODS

=over

=item   QLinearGradient()

=item   QLinearGradient(const QPointF & start, const QPointF & finalStop)

=item   QLinearGradient(qreal xStart, qreal yStart, qreal xFinalStop, qreal yFinalStop)

=item  QPointF finalStop()

=item  void setFinalStop(const QPointF & stop)

=item  void setFinalStop(qreal x, qreal y)

=item  void setStart(const QPointF & start)

=item  void setStart(qreal x, qreal y)

=item  QPointF start()


=back

=head1 ENUM VALUES

=over


=back

=head2 EXPORT

None by default.

=head1 AUTHOR

Dongxu Ma E<lt>dongxu@cpan.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2011 - 2011 by Dongxu Ma

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

See L<http://dev.perl.org/licenses/artistic.html>

=cut
